<?php
class ControllerExtensionTotalDiscountOnShipping extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('extension/total/discount_on_shipping');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('setting/setting');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$this->model_setting_setting->editSetting('total_discount_on_shipping', $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=total', true));
		}

		$data['heading_title'] = $this->language->get('heading_title');

		$data['text_edit'] = $this->language->get('text_edit');
		$data['text_enabled'] = $this->language->get('text_enabled');
		$data['text_disabled'] = $this->language->get('text_disabled');
		$data['text_none'] = $this->language->get('text_none');

		$data['entry_shipping'] = $this->language->get('entry_shipping');
		$data['entry_discount'] = $this->language->get('entry_discount');
		$data['entry_logic'] = $this->language->get('entry_logic');
		$data['entry_payment'] = $this->language->get('entry_payment');
		$data['entry_discountname'] = $this->language->get('entry_discountname');

		$data['logic_donotcount'] = $this->language->get('logic_donotcount');
		$data['logic_onlyselected'] = $this->language->get('logic_onlyselected');
		$data['logic_onlynotselected'] = $this->language->get('logic_onlynotselected');
		
		$data['ps_message'] = $this->language->get('ps_message');
		
		$data['entry_status'] = $this->language->get('entry_status');
		$data['entry_sort_order'] = $this->language->get('entry_sort_order');

		$data['button_save'] = $this->language->get('button_save');
		$data['button_cancel'] = $this->language->get('button_cancel');

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=total', true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/total/discount_on_shipping', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['action'] = $this->url->link('extension/total/discount_on_shipping', 'user_token=' . $this->session->data['user_token'], true);
		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=total', true);

		if (isset($this->request->post['total_discount_on_shipping_status'])) {
			$data['discount_on_shipping_status'] = $this->request->post['total_discount_on_shipping_status'];
		} else {
			$data['discount_on_shipping_status'] = $this->config->get('total_discount_on_shipping_status');
		}

		if (isset($this->request->post['total_discount_on_shipping_sort_order'])) {
			$data['discount_on_shipping_sort_order'] = $this->request->post['total_discount_on_shipping_sort_order'];
		} else {
			$data['discount_on_shipping_sort_order'] = $this->config->get('total_discount_on_shipping_sort_order');
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');
		
		$data['shippings'] = $this->getShippings();
		$data['payments']  = $this->getPayments();
		
		$this->response->setOutput($this->load->view('extension/total/discount_on_shipping', $data));
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/total/discount_on_shipping')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		return !$this->error;
	}
	
	private function getShippings() {

		$this->load->language('extension/total/discount_on_shipping');
		$moduleName = $this->language->get('heading_title');
		
		$data['shippings'] = array();

		$files = glob(DIR_APPLICATION . 'controller/extension/shipping/*.php');
		if ($files) {
			foreach ($files as $file) {
				$extension = basename($file, '.php');
				
				$this->load->language('extension/shipping/' . $extension);
				
				if ($this->config->get('shipping_' . $extension . '_status') > 0) {
				
					if (isset($this->request->post['total_discount_'.$extension])) {
						$value = $this->request->post['total_discount_on_shipping_'.$extension];
					} else {
						$value = $this->config->get('total_discount_on_shipping_'.$extension);
					}
				
					if (isset($this->request->post['total_discount_'.$extension])) {
						$logic = $this->request->post['total_discount_on_shipping_'.$extension.'_andlogic'];
					} else {
						$logic = $this->config->get('total_discount_on_shipping_'.$extension.'_andlogic');
					}
					
					if (isset($this->request->post['total_discount_'.$extension])) {
						$payment = $this->request->post['total_discount_on_shipping_'.$extension.'_payment'];
					} else {
						$payment = $this->config->get('total_discount_on_shipping_'.$extension.'_payment');
					}	

					if (isset($this->request->post['total_discount_'.$extension])) {
						$discountName = $this->request->post['total_discount_on_shipping_'.$extension.'_discountName'];
					} else {
						$discountName = $this->config->get('total_discount_on_shipping_'.$extension.'_discountName');
					}
					if(empty($discountName))
						$discountName = $moduleName;
					
								
					$data['shippings'][] = array(
						'name'       => $this->language->get('heading_title'),
						'extension'  => $extension,
						'discount'	 => $value,
						'andlogic'   => $logic,
						'payment'	 => $payment,
						'discountName' => $discountName
					);
				}
			}
		}
		return $data['shippings'];
	}
	

	private function getPayments() {

		$data['payments'] = array();

		$files = glob(DIR_APPLICATION . 'controller/extension/payment/*.php');
		if ($files) {
			foreach ($files as $file) {
				$extension = basename($file, '.php');

				$this->load->language('extension/payment/' . $extension);
				
				if ($this->config->get('payment_' . $extension . '_status') > 0) {	
				
					$data['payments'][] = array(
						'name'       => $this->language->get('heading_title'),
						'extension'  => $extension
					);
				}
			}
		}
		return $data['payments'];
	}	
}